/* This source code in this file is licensed to You by Castle Technology
 * Limited ("Castle") and its licensors on contractual terms and conditions
 * ("Licence") which entitle you freely to modify and/or to distribute this
 * source code subject to Your compliance with the terms of the Licence.
 * 
 * This source code has been made available to You without any warranties
 * whatsoever. Consequently, Your use, modification and distribution of this
 * source code is entirely at Your own risk and neither Castle, its licensors
 * nor any other person who has contributed to this source code shall be
 * liable to You for any loss or damage which You may suffer as a result of
 * Your use, modification or distribution of this source code.
 * 
 * Full details of Your rights and obligations are set out in the Licence.
 * You should have received a copy of the Licence with this source code file.
 * If You have not received a copy, the text of the Licence is available
 * online at www.castle-technology.co.uk/riscosbaselicence.htm
 */
/****************************************************************************
 * This source file was written by Acorn Computers Limited. It is part of   *
 * the RISCOS library for rendering RISCOS Draw files from applications     *
 * in C. It may be used freely in the creation of programs for Archimedes.  *
 * It should be used with Acorn's C Compiler Release 3 or later.            *
 *                                                                          *
 ***************************************************************************/

/* 
 * Title:   drawferror.h
 * Purpose: Definition of error codes and standard messages
 *          for the Drawfile rendering functions.
 *
 */

/*
 *
 * For each error, a code and the standard message are listed.
 * See drawfdiag.h for how to use the errors.
 *
 */

#ifndef __drwaferror_h
#define __drawferror_h

#define draw_BadObject       1 /* 'Bad object' */
#define draw_BadObjectHandle 2 /* 'Bad object handle' */
#define draw_TooManyFonts    3 /* 'Too many font definitions' */

#define draw_BBoxWrong       101 /* 'Bounding box coordinates are in the
                                  * wrong order'
                                  */
#define draw_BadCharacter    102 /* 'Bad character in string' */
#define draw_ObjectTooSmall  103 /* 'Object size is too small' */
#define draw_ObjectTooLarge  104 /* 'Object size is too large' */
#define draw_ObjectNotMult4  105 /* 'Object size is not a multiple of 4' */
#define draw_ObjectOverrun   106 /* 'Object data is larger than specified
                                  * size'
                                  */
#define draw_ManyFontTables  107 /* 'There is more than one font table' */
#define draw_LateFontTable   108 /* 'The font table appears after text
                                  * object(s)'
                                  */
#define draw_BadTextStyle    109 /* 'Bad text style word' */
#define draw_MoveMissing     110 /* 'Path must start with a move' */
#define draw_BadPathTag      111 /* 'Path contains an invalid tag' */
#define draw_NoPathElements  112 /* 'Path does not contain any line or curve
                                  * elements'
                                  */
#define draw_PathExtraData   113 /* 'There is extra data present at the end
                                  * of a path object'
                                  */
#define draw_BadSpriteSize   114 /* 'The sprite definition size is
                                  * inconsistent with the object size'
                                  */
#define draw_BadTextColumnEnd 115 /* 'Missing end marker in text columns' */
#define draw_ColumnsMismatch 116 /* 'Actual number of columns in a text area
                                  * object does not match specified number
                                  * of columns'
                                  */
#define draw_NonZeroReserved 117 /* 'Non-zero reserved words in a text area
                                  * object'
                                  */
#define draw_NotDrawFile     118 /* 'This is not a Draw file' */
#define draw_VersionTooHigh  119 /* 'Version number too high' */
#define draw_BadObjectType   120 /* 'Unknown object type' */
#define draw_CorruptTextArea 121 /* 'Corrupted text area (must start with
                                  *  '\!')'
                                  */
#define draw_TextAreaVersion 121 /* 'Text area version number is wrong or
                                  *  missing' 
                                  */
#define draw_MissingNewline  122 /* 'Text area must end with a newline
                                  * character'
                                  */
#define draw_BadAlign        123 /* 'Text area: bad \A code(must be L, R, C
                                  * or D)'
                                  */
#define draw_BadTerminator   124 /* 'Text area: bad number or missing
                                  * terminator'
                                  */
#define draw_ManyDCommands   125 /* 'Text area: more than one \D command' */
#define draw_BadFontNumber   126 /* 'Text area: bad font number' */
#define draw_UnexpectedCharacter 127 /* 'Text area: unexpected character
                                      * in \F command'
                                      */
#define draw_BadFontWidth    128 /* 'Text area: bad or missing font width
                                  * in \F command'
                                  */
#define draw_BadFontSize     129 /* 'Text area: bad or missing font size
                                  * in \F command'
                                  */
#define draw_NonDigitV       130 /* 'Text area: non-digit in \V command' */
#define draw_BadEscape       131 /* 'Text area: bad escape sequence' */
#define draw_FewColumns      133 /* 'Text area must have at least one
                                  * column'
                                  */
#define draw_TextColMemory   134 /* 'Out of memory when building text area'
                                  * [location field is always 0 for this
                                  * error]
                                  */

#endif

/* end of drawferror.h */
